@@ -43,7 +43,7 @@ MainWindow::MainWindow(const KUrl& url)
     setupActions();
 
     connect(m_main, SIGNAL(welcomeScreen()), this, SLOT(welcomeScreen()));
-    connect(m_main, SIGNAL(startingGame()), this, SLOT(startingGame()));
+    connect(m_main, SIGNAL(placeShips()), this, SLOT(startingGame()));
     
     m_main->newGame();
 
@@ -54,7 +54,7 @@ MainWindow::MainWindow(const KUrl& url)
 void MainWindow::setupActions()
 {
     KStandardGameAction::gameNew(m_main, SLOT(newGame()), actionCollection());
-    KStandardGameAction::restart(m_main, SLOT(restart()), actionCollection());     
+    KStandardGameAction::restart(m_main, SLOT(restart()), actionCollection());
     KStandardGameAction::highscores(m_main, SLOT(highscores()), actionCollection());
     
     KStandardGameAction::quit(this, SLOT(close()), actionCollection());
@@ -81,6 +81,11 @@ void MainWindow::setupActions()
     action->setChecked(Settings::adjacentShips());
     actionCollection()->addAction("options_adjacent", action);
     connect(action, SIGNAL(triggered(bool)), m_main, SLOT(toggleAdjacent(bool)));
+    // This action will be disabled when a game is being run
+    action = new KToggleAction(i18n("&Multiple Ships"), this);
+    action->setChecked(Settings::severalShips());
+    actionCollection()->addAction("options_multiple_ships", action);
+    connect(action, SIGNAL(triggered(bool)), m_main, SLOT(toggleMultiple(bool)));
     // config end of game message
     action = new KToggleAction(i18n("Show End-of-Game Message"), this);
     action->setChecked(true);
