@@ -25,7 +25,7 @@ Q_OBJECT
     Shot* m_pending_shot;
     bool m_client;
     bool m_winner;
-
+    
 public:
     NetworkEntity(Sea::Player player, Sea* sea, SeaView* seaview, Protocol* device, bool client);
     ~NetworkEntity();
@@ -34,16 +34,20 @@ public:
     virtual void notifyChat(const Entity* entity, const QString& text);
     virtual void notifyNick(Sea::Player player, const QString& nick);
     virtual void start(bool ask);
+    virtual void startPlacing(bool ask);
     virtual void startPlaying();
     virtual void notifyReady(Sea::Player player);
     virtual void notifyShips(Sea::Player winner);
     virtual void notifyGameOver(Sea::Player winner);
+    virtual void notifyGameOptions(bool ask);
+    virtual void notifyRestart(Sea::Player);
     virtual void hit(Shot* shot);
 
     virtual KIcon icon() const;
 private slots:
     void received(MessagePtr msg);
     virtual void notifyAbort();
+    virtual void notifyRestartPlacing(Sea::Player player) { };
 protected:
     virtual void visit(const HeaderMessage& msg);
     virtual void visit(const RejectMessage& msg);
