@@ -20,19 +20,22 @@ class MessageSender : public MessageVisitor
 {
     QDomDocument m_doc;
     QDomElement m_main;
-    
-    void addField(const QString& key, const QString& value)
+
+    QDomElement addField(const QString& key, const QString& value)
     {
         QDomElement element = m_doc.createElement(key);
         QDomText text = m_doc.createTextNode(value);
         element.appendChild(text);
         m_main.appendChild(element);
+        return element;
     }
-    
+
     template <typename Msg>
     void setType(const Msg&)
     {
-        addField("msgtype", QString::number(Msg::MSGTYPE));
+        QDomElement element = addField("msgtype", QString::number(Msg::MSGTYPE));
+        // only useful for debuging, just add the name of the message type
+        element.setAttribute(QLatin1String("type"), Msg::messageType());
     }
 public:
     MessageSender()
@@ -111,9 +114,20 @@ public:
 
     virtual void visit(const GameOptionsMessage& msg)
     {
+        // create the message XML contents
         setType(msg);
         ADD_FIELD(msg, enabledAdjacentShips);
-        ADD_FIELD(msg, oneOrSeveralShips);
+        QDomElement oneOrElement=addField ("oneOrSeveralShips", QString(msg.oneOrSeveralShips()));
+        oneOrElement.setAttribute(QLatin1String("longestShip"),QString::number(msg.shipsConfiguration()->longestShip()));
+        addField("boardWidth", QString::number(msg.gridWidth()));
+        addField("boardHeight", QString::number(msg.gridHeight()));
+        for (unsigned int i=1; i<=msg.shipsConfiguration()->longestShip(); i++) {
+            QDomElement element=addField(QString("ships"), QLatin1String( "" ));
+            element.setAttribute(QLatin1String("size"),QString::number(i));
+            element.setAttribute(QLatin1String("number"),QString::number(msg.shipsConfiguration()->numberOfShipsOfSize(i)));
+            element.setAttribute(QLatin1String("name"),msg.shipsConfiguration()->nameOfShipsOfSize(i));
+            element.setAttribute(QLatin1String("pluralName"),msg.shipsConfiguration()->pluralNameOfShipsOfSize(i));
+        }
     }
 };
 
@@ -244,9 +258,42 @@ MessagePtr Protocol::parseMessage(const QString& xmlMessage)
         }
     case GameOptionsMessage::MSGTYPE:
         {
+            // get values from the xml message
             DEF_ELEMENT(enabledAdjacentShips);
-            DEF_ELEMENT(oneOrSeveralShips);
-            return MessagePtr(new GameOptionsMessage(enabledAdjacentShips, oneOrSeveralShips));
+            bool adjacentShips = enabledAdjacentShips=="true";
+            QDomElement oneOrElement=main.namedItem(QLatin1String("oneOrSeveralShips")).toElement();
+            QString oneOrSeveralShips = oneOrElement.text();
+            bool severalShips = oneOrSeveralShips=="true";
+            unsigned int longestShip=0;
+            // if the node oneOrSeveralShips does not have the attribute, then it is the single ships configuration.
+            if ( !oneOrElement.hasAttribute(QLatin1String("longestShip")) ) {
+                return MessagePtr(new GameOptionsMessage(adjacentShips, severalShips, BattleShipsConfiguration::defaultSingleShipsConfiguration(adjacentShips, true)));
+            }
+            else {
+                longestShip = oneOrElement.attribute(QLatin1String("longestShip")).toUInt();
+            }
+            DEF_ELEMENT(boardWidth);
+            DEF_ELEMENT(boardHeight);
+            unsigned int width=boardWidth.toUInt();
+            unsigned int height=boardHeight.toUInt();
+            // and get the ships configuration
+            QDomNodeList nodes = main.childNodes();
+            BattleShipsConfiguration battleShipsConfiguration(longestShip, adjacentShips, width, height, true);
+            for (int i = 0; i < nodes.count(); i++) {
+                QDomElement element = nodes.item(i).toElement();
+                if (!element.isNull() && element.tagName()==QLatin1String("ships")) {
+                    QString name=element.attribute(QLatin1String("name"));
+                    QString pluralName=element.attribute(QLatin1String("pluralName"));
+                    unsigned int size=element.attribute(QLatin1String("size")).toUInt();
+                    unsigned int number=element.attribute(QLatin1String("number")).toUInt();
+                    battleShipsConfiguration.addShips(size,number,name,pluralName);
+                }
+            }
+            if ( !battleShipsConfiguration.isAValidConfiguration() )
+            {
+               return MessagePtr(new GameOptionsMessage(adjacentShips, severalShips, BattleShipsConfiguration::defaultSingleShipsConfiguration(adjacentShips, true)));
+            }
+            return MessagePtr(new GameOptionsMessage(adjacentShips, severalShips, battleShipsConfiguration));
         }
     default:
         emit parseError("Unknown message type");
